#
# spec file for package mediastreamer2
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define sobase  libmediastreamer2
%define sover   11

Name:           mediastreamer2
Version:        5.3.95
Release:        1.1
Summary:        Audio/Video real-time streaming
License:        AGPL-3.0-or-later
Group:          Productivity/Telephony/Utilities
URL:            https://linphone.org/technical-corner/mediastreamer2
Source:         https://gitlab.linphone.org/BC/public/mediastreamer2/-/archive/%{version}/%{name}-%{version}.tar.bz2
Patch0:         mediastreamer2-fix-pkgconfig.patch
Patch1:         fix-srtp2-linphone.patch
Patch2:         fix-build-ffmpeg5.patch
Patch3:         fix_soversion.patch
Patch4:         set_current_version.patch
%if 0%{?suse_version} >= 1600
BuildRequires:  liboqs-devel
# At the time of writing (22/Dec/2023), PQCE is only available on Tumbleweed.
BuildRequires:  postquantumcryptoengine-devel >= 5.3.0~git.20230802
%endif
BuildRequires:  Mesa-libGL-devel
BuildRequires:  bcmatroska2-devel >= 5.3.0
BuildRequires:  broadvoice16-devel
BuildRequires:  cmake >= 3.22
BuildRequires:  doxygen
BuildRequires:  gawk
BuildRequires:  gcc-c++
BuildRequires:  graphviz
BuildRequires:  libgsm-devel
BuildRequires:  libjpeg-turbo >= 2.0.0
BuildRequires:  libpcap-devel
BuildRequires:  libsrtp2-linphone-devel
BuildRequires:  libv4l-devel
BuildRequires:  libvpx-devel
BuildRequires:  libxml2-devel
BuildRequires:  pkgconfig
BuildRequires:  spandsp-devel
BuildRequires:  sqlite3-devel
BuildRequires:  vim
%if 0%{?suse_version} >= 1600
%ifarch x86_64
BuildRequires:  libyuv-devel
BuildRequires:  zxing-cpp-devel
BuildRequires:  cmake(Qt5Quick)
BuildRequires:  pkgconfig(Qt5OpenGL)
%endif
%endif
BuildRequires:  libjpeg-devel >= 8.2.0
BuildRequires:  pkgconfig(alsa)
BuildRequires:  pkgconfig(bctoolbox) >= %{version}
BuildRequires:  pkgconfig(glew)
BuildRequires:  pkgconfig(glu)
BuildRequires:  pkgconfig(libavcodec) >= 51.0.0
BuildRequires:  pkgconfig(libbcg729)
BuildRequires:  pkgconfig(libbzrtp) >= %{version}
BuildRequires:  pkgconfig(libpulse)
BuildRequires:  pkgconfig(libswscale) >= 0.7.0
BuildRequires:  pkgconfig(libupnp)
BuildRequires:  pkgconfig(opus)
BuildRequires:  pkgconfig(ortp) >= %{version}
BuildRequires:  pkgconfig(speex)
BuildRequires:  pkgconfig(speexdsp)
BuildRequires:  pkgconfig(theora)
BuildRequires:  pkgconfig(x11)
BuildRequires:  pkgconfig(xext)
BuildRequires:  pkgconfig(xv)

%description
Mediastreamer2 is a library to make audio and video real-time
streaming and processing. It is written in pure C and based upon the
oRTP library.

%package -n %{sobase}-%{sover}
Summary:        Audio/video real-time streaming library, base part
Group:          System/Libraries

%description -n %{sobase}-%{sover}
Mediastreamer2 is a library to make audio and video real-time
streaming and processing. It is written in pure C and based upon the
oRTP library.

%package doc
Summary:        Documentation for the mediastreamer2 library
Group:          Documentation/HTML
Requires:       %{name} = %{version}

%description doc
Mediastreamer2 is a library to make audio and video real-time
streaming and processing. It is written in pure C and based upon the
oRTP library.

This package contains documentation files

%package devel
Summary:        Headers and libraries for the mediastreamer2 library
Group:          Development/Libraries/C and C++
Requires:       %{name} = %{version}
Requires:       %{sobase}-%{sover} = %{version}
Requires:       bcmatroska2-devel

%description devel
Mediastreamer2 is a library to make audio and video real-time
streaming and processing. It is written in pure C and based upon the
oRTP library.

This package contains header files and development libraries needed to
develop programs using the mediastreamer2 library.

%prep
%autosetup -N
%patch -P 0 -p1
%patch -P 1 -p1
if pkg-config --atleast-version 59.37.100 libavcodec; then
%patch -P 2 -p1
fi
%patch -P 3 -p1
%patch -P 4 -p1

%build
export CFLAGS="%(echo %{optflags}) -fcommon -Wno-implicit-function-declaration -I%_includedir/bcmatroska2 -I%_includedir/corec"
export CXXFLAGS="$CFLAGS"
%cmake \
    -DCMAKE_SHARED_LINKER_FLAGS="-flto=auto -Wl,--as-needed -Wl,-z,now" \
%if 0%{?suse_version} >= 1600
%ifarch x86_64
    -DENABLE_QT_GL=ON \
%endif
%endif
    -DBUILD_SHARED_LIBS=ON \
    -DENABLE_STRICT=NO
%cmake_build

%install
%cmake_install

mkdir -p %{buildroot}/%{_libdir}/mediastreamer/plugins
mkdir -p %{buildroot}%{_docdir}/%{name}/
mv -T %{buildroot}%{_datadir}/doc/%{name}-%{version}/ \
  %{buildroot}%{_docdir}/%{name}/

%post -n %{sobase}-%{sover} -p /sbin/ldconfig
%postun -n %{sobase}-%{sover} -p /sbin/ldconfig

%files
%license LICENSE.txt
%{_bindir}/mediastreamer2-mediastream
%{_bindir}/mediastreamer2-mkvstream
%dir %{_libdir}/mediastreamer
%dir %{_libdir}/mediastreamer/plugins
%if 0%{?suse_version} >= 1600
%ifarch x86_64
%{_libdir}/mediastreamer/plugins/libmsqogl.so
%endif
%endif

%files -n %{sobase}-%{sover}
%{_libdir}/%{sobase}.so.%{sover}*

%files doc
%doc README.md
%dir %{_docdir}/%{name}/
%doc %{_docdir}/%{name}/*
%dir %{_datadir}/images/
%{_datadir}/images/nowebcamCIF.jpg

%files devel
%dir %{_includedir}/OpenGL
%dir %{_includedir}/OpenGL/EGL
%dir %{_includedir}/OpenGL/GLES2
%dir %{_includedir}/OpenGL/GLES3
%dir %{_includedir}/OpenGL/KHR
%{_includedir}/mediastreamer2/
%{_includedir}/OpenGL/EGL/egl.h
%{_includedir}/OpenGL/EGL/eglext.h
%{_includedir}/OpenGL/EGL/eglplatform.h
%{_includedir}/OpenGL/GLES2/gl2.h
%{_includedir}/OpenGL/GLES2/gl2ext.h
%{_includedir}/OpenGL/GLES2/gl2platform.h
%{_includedir}/OpenGL/GLES3/gl3.h
%{_includedir}/OpenGL/GLES3/gl31.h
%{_includedir}/OpenGL/GLES3/gl32.h
%{_includedir}/OpenGL/GLES3/gl3platform.h
%{_includedir}/OpenGL/KHR/khrplatform.h
%{_includedir}/OpenGL/LICENSE
%{_includedir}/OpenGL/README.md
%{_includedir}/OpenGL/angle_windowsstore.h
%{_bindir}/mediastreamer2-tester
%{_libdir}/libmediastreamer2.so
%{_datadir}/mediastreamer2-tester/
%{_datadir}/Mediastreamer2/
%{_libdir}/pkgconfig/mediastreamer.pc

%changelog
* Mon Nov 11 2024 ecsos <ecsos@opensuse.org>
- Update to 5.3.95 (no changelog).
* Sat May 25 2024 Giacomo Comes <gcomes.obs@gmail.com>
- add patch fix_soversion.patch
- add package libmediastreamer2-11 containing libmediastreamer2.so.11
  * do no pack such library in package mediastreamer2-devel
    otherwise when installing linphone-desktop a bunch of unnecessary
    devel packages get installed as well
* Thu May 16 2024 Giacomo Comes <gcomes.obs@gmail.com>
- specify in CFLAGS the location of the bcmatroska2 header files
* Fri Mar 29 2024 Paolo Stivanin <info@paolostivanin.com>
- Update to 5.3.37 (no changelog).
* Thu Mar  7 2024 Paolo Stivanin <info@paolostivanin.com>
- Update to 5.3.26 (no changelog).
* Fri Feb 23 2024 pgajdos@suse.com
- Use %%patch -P N instead of deprecated %%patchN.
* Mon Jan 15 2024 Paolo Stivanin <info@paolostivanin.com>
- Update to 5.3.7:
  ADDED:
  * AV1 codec added
  * SRTP GCM mode
  * Add MS_FILTER_IS_HW_ACCELERATED MSFilter flag to advertise hw-accelerated codecs
  * Dummy codec, to avoid fatal errors when a encoder/decoder is not available
  * Double SRTP encryption (experimental)
  CHANGED:
  * Removed legacy platform abstraction code, now provided by bctoolbox.
  * Various optimisations for video processing on Android platform
  FIXED:
  * Fix buffer overflow in GenericPLC filter.
  * Issue with H264 decoding of malformed RTP streams
- Rebase patches.
* Fri Dec 22 2023 Paolo Stivanin <info@paolostivanin.com>
- Add missing deps on TW.
* Tue Nov 21 2023 Paolo Stivanin <info@paolostivanin.com>
- Add ENABLE_QT_GL for x86_64 (boo#1217352).
* Sun Oct  8 2023 thod_@gmx.de
- Remove BuildRequires: vim, not needed
- Fix BuildRequires for Fedora
* Mon Aug 28 2023 Paolo Stivanin <info@paolostivanin.com>
- Update to 5.2.98 (no changelog)
* Sat Aug  5 2023 Giacomo Comes <gcomes.obs@gmail.com>
- Add BuildRequires:  Mesa-libGL-devel
  * fix build on tumbleweed
* Wed Jun 28 2023 Paolo Stivanin <info@paolostivanin.com>
- Update to 5.2.73 (no changelog)
- Rebase fix-build-ffmpeg5.patch
* Fri Apr  7 2023 Paolo Stivanin <info@paolostivanin.com>
- Update to 5.2.49 (no changelog).
- Add set_current_version.patch.
* Wed Mar  8 2023 Paolo Stivanin <info@paolostivanin.com>
- Update to 5.2.30 (no changelog)
* Wed Jan 11 2023 Giacomo Comes <gcomes.obs@gmail.com> - 5.2.9
- Update to version 5.2.9:
  * Fix a crash due to a race condition in conference server
  * Add logs to troubleshoot inactive streams issue
* Wed Jan  4 2023 Paolo Stivanin <info@paolostivanin.com>
- Update to 5.2.6:
  * Added
    + Video conferencing features
    + RFC6464 client-to-mixer
    + RFC6465 mixer-to-client
    + Video conference: added CSRC of contributor to active speaker stream.
    + Add support for post-quantum encryption algorithms within ZRTP protocol.
  * Changed
    + Licence becomes AGPL-3.
    + Improvements to Android bluetooth audio support.
    + Performance improvements to Android Texture video renderer.
    + Optimizations to DTLS handshake to be more robust to packet losses.
    + libyuv used for rescaling and pixel conversion (instead of libswscale).
  * Fixed
    + Crash with buffer overflow in GenericPLC filter.
    + ARM64/linux compilation.
    + MSVideoRouter algorithm improved.
* Mon Oct 17 2022 Paolo Stivanin <info@paolostivanin.com>
- Update to 5.1.64 (no changelog).
* Thu Sep  8 2022 Bjørn Lie <bjorn.lie@gmail.com>
- Add fix-build-ffmpeg5.patch: Fix build with ffmpeg-5. Apply patch
  only when libavcodec is from ffmpeg version 5 or newer.
* Sun Aug 14 2022 thod_@gmx.de
- Remove RPATH to be able to build on Fedora
* Fri Jul  8 2022 Paolo Stivanin <info@paolostivanin.com>
- Update to version 5.1.45:
  * Make DTLS-SRTP to start immediately after the default candidate pair is verified by ICE.
  * Prevent default sound device descriptor to use BUILTIN_AEC flags if AcousticEchoCanceler isn't available.
  * Fix an issue where audio stops when trying to send a DTMF while no telephone-event payload types are configured in the session.
  * Do not add audio devices detected as “UNKNOWN” type.
  * Fix audio route change event size, which was too big and could create unexpected behaviours.
* Wed Jun  8 2022 Giacomo Comes <gcomes.obs@gmail.com> - 5.1.32
- Update to version 5.1.32:
  * Fix a crash/no webcam behaviour with msmfoundation
  * manger reload is requested if audio routes add/remove device
* Sat May  7 2022 Giacomo Comes <gcomes.obs@gmail.com>
- Update to version 5.1.29:
  * use ticker_synchronizer to fix audio delay when switching audio route
  * fixed issue with OpenSLES sound card refs & capabilities
- revert license tag change
* Wed May  4 2022 Jan Engelhardt <jengelh@inai.de>
- Stop using SRTP1
- Drop baselibs.conf (no further library appears to use it)
* Mon May  2 2022 Paolo Stivanin <info@paolostivanin.com>
- Update to 5.1.20:
  * no changelog
* Thu Mar 24 2022 Paolo Stivanin <info@paolostivanin.com>
- Update to 5.1.15:
  * no changelog
* Tue Mar  1 2022 Paolo Stivanin <info@paolostivanin.com>
- Update to version 5.1.3:
  * Experimental Forward Error Correction feature for video streams.
  * Mkv and Wav file player and recorders file I/O is tunneled through
    bctbx VFS API.
* Tue Feb  1 2022 Giacomo Comes <gcomes.obs@gmail.com> - 5.0.67
- Update to version 5.0.67:
  * no changes
- fix license tag
* Tue Jan 18 2022 Paolo Stivanin <info@paolostivanin.com>
- Update to 5.0.66:
  * no changelog
* Sun Dec  5 2021 Max Lin <mlin@suse.com>
- Update license to GPL-3.0-or-later
* Sun Nov 21 2021 Giacomo Comes <gcomes.obs@gmail.com> - 5.0.53
- Update to version 5.0.53:
  * Add extra log traces when setting input/output audio device
* Mon Nov  8 2021 Giacomo Comes <gcomes.obs@gmail.com> - 5.0.49
- Update to 5.0.49:
  * Add a way to change volume on ALSA with MSFilterAudioPlaybackInterface
    and MSFilterAudioCaptureInterface
* Tue Nov  2 2021 Giacomo Comes <gcomes.obs@gmail.com> - 5.0.46
- Update to 5.0.46:
  * Delete unnedded log
* Tue Oct 19 2021 Giacomo Comes <gcomes.obs@gmail.com> - 5.0.36
- Update to 5.0.36:
  * Fix tone manager issues and crash with a full refactoring
- remove 0001-Fix-build-with-GCC-11.patch
- add BuildRequires:  broadvoice16-devel
* Fri Oct 15 2021 Paolo Stivanin <info@paolostivanin.com>
- Update to 5.0.35:
  * no changelog
* Fri Jul 30 2021 Paolo Stivanin <info@paolostivanin.com>
- Update to 5.0.3:
  * no changelog
* Thu Jul 29 2021 Giacomo Comes <gcomes.obs@gmail.com> - 5.0.0
- SRTP_LIBRARIES not found during build, fixing fix-srtp2-linphone.patch
* Wed Jul 14 2021 Paolo Stivanin <info@paolostivanin.com>
- Update to 5.0.0:
  * added API to change media encryption in the fly
  * refactoring and simplifications for the MSOgl filter
    (video OpenGL rendering)
  * fixed absence of dummy stun packets when DTLS is used with
    "encryption_mandatory" preventing DTLS handshare to take place
- Add dependency on bcmatroska2 >= 0.23.1 since this release introduces
  a new method required by mediastreamer 5.0
- Add fix-srtp2-linphone.patch
* Thu Jun 24 2021 Matej Cepl <mcepl@suse.com>
- We actually don't need python2 BR at all, it seems.
* Tue Jun 22 2021 Paolo Stivanin <info@paolostivanin.com>
- Update to 4.5.20 (no changelog)
* Mon Jun  7 2021 Paolo Stivanin <info@paolostivanin.com>
- Update to 4.5.16 (no changelog)
- Bump min requirement for libjpeg-turbo to 2.0.0
* Fri May 14 2021 Paolo Stivanin <info@paolostivanin.com>
- Update to 4.5.15 (no changelog)
* Wed Apr 28 2021 Paolo Stivanin <info@paolostivanin.com>
- Update to 4.5.10 (no changelog)
* Thu Apr 15 2021 Luiz Angelo Daros de Luca <luizluca@tre-sc.jus.br>
- Update to 4.5.3:
  * No changelog available.
* Wed Mar 31 2021 Paolo Stivanin <info@paolostivanin.com>
- Update to 4.5.0:
  + Added
  * New camera capture backend based on Windows MediaFoundation
  * MSMediaPlayer enhancements.
  * VideoConference API and engine prototype (active speaker switching only)
  + Changed
  * audio flow control algorithm improved, silent portions are dropped first.
  * MKVPlayer supports seek in files without cue table.
    'packetlosspercentage' is now configurable in opus encoder.
  + Fixed
  * misfunction in DTLS handshake over TURN
  * fix arythmetic issue in clock skew computation, causing bad audio when the sound device outputs
  * audio fragments not multiple of 10ms.
  * wrong selection of ICE TURN candidates when the TURN server is behind a firewall
  * unsent TURN SenderIndication packets on iOS
  * fix video freeze in VP8, due to lack of retransmission of SLIs.
  * All these fix were backported to 4.4 branch.
* Tue Mar  9 2021 Paolo Stivanin <info@paolostivanin.com>
- Update to 4.4.33 (no changelog)
* Mon Feb 22 2021 Paolo Stivanin <info@paolostivanin.com>
- Update to 4.4.29 (no changelog)
* Wed Feb 10 2021 Christophe Giboudeaux <christophe@krop.fr>
- Add patch to fix build with GCC 11 (boo#1181920)
  * 0001-Fix-build-with-GCC-11.patch
* Fri Jan 22 2021 Jan Engelhardt <jengelh@inai.de>
- Trim redundancies from the description.
* Fri Jan 22 2021 Paolo Stivanin <info@paolostivanin.com>
- Update to 4.4.24 (no changelog)
* Thu Dec 31 2020 Paolo Stivanin <info@paolostivanin.com>
- Update to 4.4.21 (no changelog)
* Wed Dec  2 2020 Paolo Stivanin <info@paolostivanin.com>
- Update to 4.4.13 (no changelog)
* Thu Nov 12 2020 Paolo Stivanin <info@paolostivanin.com>
- Update to 4.4.7 (no changelog)
* Wed Nov  4 2020 Paolo Stivanin <info@paolostivanin.com>
- Update to 4.4.6 (no changelog)
* Fri Sep 25 2020 Paolo Stivanin <info@paolostivanin.com>
- Update to 4.4.2 (no changelog)
* Fri Jun 26 2020 Paolo Stivanin <info@paolostivanin.com>
- Update to 4.4.0
  * TURN over TCP or TLS (previously was only UDP)
  * Capture/playback gain control for Mac OS (AudioUnit)
  * Optimize mirroring for OpenGL based display filters. It was previously done in software.
  * Make V4L2 capture filter work with read-only devices (such as with v4lloopback driver)
  * ICE: set source IP addresses of outgoing packets consistent with the local candidate it is supposed to test or use. This fixes various ICE failures occuring when the host has multiple IP addresses (which is now common with IPv6)
  * New implementation of MSEventQueue, to fix unreproductible crashes with the previous implementation.
  * Crashes around mblk_t management of Video4Linux2 catpure filter.
  * Random crash in VideoToolbox decoding filter.
  * VP8 decoding errors due to an invalid aggregation of packets in rare circumstances
  * Crash while reading mkv file with checksums.
* Wed Mar  4 2020 Paolo Stivanin <info@paolostivanin.com>
- Update to 4.3.1 (no changelog)
- Remove mediastreamer2-fix-xv.patch
- Remove mediastreamer2-2.16.1-fix-no-git.patch
* Wed Aug 15 2018 sor.alexei@meowr.ru
- Add mediastreamer2-2.16.1-fix-no-git.patch: Fix building
  out-of-git (commit de3a24b).
- Fix missing package documentation and licensing files.
* Fri Jul 21 2017 sor.alexei@meowr.ru
- Update to version 2.16.1 (changes since 2.15.1):
  * Add sound card driven ticker.
  * Sound card flow control improvements.
- Enable documentation installation.
- Switch from building with autotools to cmake.
- Add mediastreamer2-fix-pkgconfig.patch: Install mediastreamer.pc.
- Add mediastreamer2-fix-xv.patch: Fix Xv by linking with Xext.
- Build with optional TurboJpeg and Bcg729 dependencies.
* Wed May 17 2017 sor.alexei@meowr.ru
- Update to version 2.15.1 (changes since 2.14.0):
  * Support for TURN (RFC5766).
  * Support of ICE with IPv6.
  * A Bug fix in CMake scripts.
- Remove mediastreamer2-bctoolbox-pkgconfig.patch: fixed upstream.
* Thu Sep 29 2016 sor.alexei@meowr.ru
- Add mediastreamer2-bctoolbox-pkgconfig.patch: Add bctoolbox
  dependency to mediastreamer.pc.
* Mon Sep 12 2016 sor.alexei@meowr.ru
- Update to version 2.14.0 (changes since 2.12.1):
  * Add support of the H.264 hardware codec on Apple's platforms.
  * MSFactory usage: Using one MSfactory per LinphoneCore instance,
    deprecate all "static" methods, now grouped around the
    MSFactory object.
  * Add BroadVoice16 audio codec support.
  * Fix option to really disable libv4l2 when asked.
  * Bugfixes.
* Mon Jul 25 2016 olaf@aepfle.de
- Build with ffmpeg unconditional
* Wed Jun 22 2016 sor.alexei@meowr.ru
- Enable more additional build requirements.
* Fri Mar  4 2016 sor.alexei@meowr.ru
- Update to 2.12.1:
  * Fix crash in MKV recorder.
  * Fix I-frame request when starting MKV recording.
- Use tarball signing.
* Fri Nov  6 2015 sor.alexei@meowr.ru
- Update to 2.12.0:
  * Allow video stream to keep its source (camera).
  * Basic AVPF handling for H.264 codec.
  * Support of video presets (include a high-fps preset).
  * Support of RTP session as input/output of a audio/video stream
    (instead of a sound card or camera/display).
  * Add text stream for RTT (Real-Time Text).
  * Support of VP8 recording/playing in mkv files.
  * Bug fixes.
* Mon Sep 21 2015 olaf@aepfle.de
- Use pkgconfig for ffmpeg to fix build in PMBS
* Tue Sep  8 2015 sor.alexei@meowr.ru
- Build with video support outside PMBS for openSUSE Leap 42.1
  and newer (where ffmpeg is available).
- Split locales into mediastreamer2-lang.
* Sat Aug 22 2015 tbechtold@suse.com
- Use correct tar.gz file (verified signature)
* Fri Aug 21 2015 tbechtold@suse.com
- update to 2.11.2:
  * Fix build without non free codecs when building with CMake.
  * Minor release v2.11.2
  * Fix nowebcam not working with valid JPG
  * Fix issue when detecting fast CPUs on Android
  * Fix missing return on isArmv7 method for Android
  * add method to obtain the list of supported abis
  * bc_tester_utils.h: fix some macros
  * Always include static picture camera.
  * The nowebcam filter now sends a black image if the jpeg file is not found
    or if the platform does not support jpeg decoding.
  * Fix HAVE_NON_FREE_CODECS for Android
  * Fix compilation errors and memory leak.
  * Fix last commit to clean incomplete frames correctly.
  * Request sending of RPSI when a VP8 decoded frame is a golden or an altref
    frame.
  * Update ICE session state when removing a check list.
  * msvideo.c: use ms_debug instead of ms_message
  * Revert "zrtp.c: avoid copying/logging non-NULL-terminated string"
  * bc_tester_utils.h: fix missing stdarg.h
  * configure.ac: use -Wno-unused-function when using clang
  * bc_tester_utils: fix include paths
  * tester: update bc_tester_utils
  * Updated Version.java with android lollipop api codes
  * Always look for polarssl when building with CMake (needed for STUN hmac).
  * Add option to enable/disable documentation generation when building with
    CMake.
  * fix crash because of virtual refbase of AudioTrack not detected properly,
    due to reverse loop starting past end of buffer.
  * mediastreamer2_adaptive_tester.c: disable stateful tests for yet
  * Set picture format when changing camera with a source that performs
    encoding.
  * Edit previous driver log instead of adding a new one
  * Log v4l2 driver name and version
  * fix previous commit
  * workaround attempt for buggy v4l2 drivers
  * alsa.c: output logs in ORTP_MESSAGE level instead of ORTP_ERROR
  * Do not try to search for libgcc and libmingwex when building for Windows
    Phone.
  * change stupid error message into normal log.
  * configure.ac: add --enable-tools option as Linphone does
  * configure.ac: add --disable-documentation option to speed up dev builds
  * alsa.c: set error log handler in order to use ms_error instead of stderr
  * Improve the documentation of the video_preview_stop_reuse_source() function.
  * Release 2.11.1
  * zrtp.c: avoid copying/logging non-NULL-terminated string
  * both vp8 & srtp are now available on centos7, enabling for rpm
  * mediastreamer2_tester_ios.m: use ms_strdup when setting writable/readable
    directories
  * Revert crappy AEC on galaxy note - it works well generally.
  * fix stereo support again
  * fix bugs with stereo support, when encoder/decoder doesn't tell what
    number of channel is. Fix crash under vmware when msv4l2.c leaves buffers
    queued before closing.
  * Fix build with Visual Studio.
  * switch rtp destination port using received stun packet in case of symmetric
    rtp and no rtp packets received yet
  * avoid extern variable for windows
  * modified ms_zrtp_startSrtpSession to support either b256 or b32 format
    SAS string
  * allow code to work without speex resampler
  * prepare work to have symmetric rtp based on stun packet
  * tester: fix crash when using both --verbose and --log-file
  * do not retry forever to open x11/xv
  * add video stream getter on cam
  * tester: use snprintf instead of sprintf and use stdio instead of default
    logger function for bc_tester_utils
  * Fix build with CMake for Windows Phone.
  * fix broken rtcp encryption
  * Fix potential CMake error with missing arguments.
  * Add build of VP8 on Windows Phone 8.
  * bc_tester_utils.c: use tester_printf instead of fprintf
  * mediastreamer2_tester.c: correctly set log level mask
  * Set the picture format of the source when it performs the encoding.
  * Define MS_PIX_FMT_UNKNOWN first so that its value does not change when
    adding pictures formats.
  * mediastream.c: use strtol instead of atoi because of Windows not
    handling ERANGE
  * qos analyzer: add some comments
  * Add the video_stream_started() function.
  * Fix build of tester with CMake.
  * fix compilation problem
  * tester: update common & add common/ subfolder in include directories
  * mediastream_cocoa.m: use dispatch_get_global_queue instead of
    dispatch_get_main_queue in order to display windows without blocking
    the main queue
  * fix bugs in outgoing metadata support
  * add support of outgoing metadatas
  * add method to bufferizer to put meta datas to a message
  * videostream.c: remove unnecessary \n in ms_log functions
  * mediastream_cocoa.m: use display_async instead of
    performSelectorInBackground, otherwise nanosleeps are not respected
    by Darwin... (+reformat tabs)
  * fix ios compilation issue
  * autocompletion: add Linphone and mediastreamer tools as supported by
    the tool
  * fix IOS compilation
  * mediastream.c tool: improve helper and remote IP parsing when only port
    is provided (assume localhost)
  * Add ms_snd_card_manager_prepend_cards() API.
  * Tester: update CMakeLists.txt and use latest changes
  * make a better mire, which is harder to process by video encoders
  * adaptive tester: use MIR camera instead of the default one to get a
    reproductible scenario environment
  * set correct ortp requirement
  * Tester: fix return value
  * adaptive tester: disable camera optimization when using no webcam
  * adaptive tester: use MIR camera instead of the real one
  * Tester: fix utils
  * .gitignore: ignore generated executable pcap_playback
  * mediastreamer2_tester: use ORTP_MESSAGE as verbosity level
  * Tester: update
  * Tester: terminate tester_utils for mediastreamer2
  * Tester: create tester_utils which contain factorized code for all
    testers (in progress, continuing)
  * Tester: create tester_utils which contain factorized code for all
    testers (in progress, continuing)
  * Tester: create tester_utils which contain factorized code for all
    testers (in progress, continuing)
  * Tester: create tester_utils which contain factorized code for all
    testers (in progress)
  * tester: rename mediastream_tester_cocoa.m to mediastreamer2_tester_cocoa.m
    to get a more consistent name convention
  * Add test for TMMBR feedback messages.
  * fix compilation issue
  * fix ms2 build without srtp
  * Fix crash
  * Allow x86_64 simulator ios compilation
  * Fix "AVPF RPSI count" test where the required bitrate was not initialized.
  * Do not force computation of send bandwidth in the test, it is done
    automatically by oRTP.
  * Include missing CheckSymbolExists.
- Adjust Requires according to configure.ac
* Sun Apr  5 2015 fisiu@opensuse.org
- Build with zrtp support: fix boo#903431.
* Mon Mar 23 2015 sor.alexei@meowr.ru
- Add zRTP encryption support.
- Add baselibs.conf.
* Mon Mar 16 2015 sor.alexei@meowr.ru
- Update to 2.11.0:
  * Support of AVPF with VP8 codec only.
  * Support of Matroska file format (needs libmatroska2).
  * Audio/video stream recorder. Only H264 is supported for video
    stream.
  * Add functions to the API to send audio/video streams read from
    a file (only WAV and MKV file formats are supported).
  * Add functions to the API to play multimedia files and display
    to a specified drawing surface.
  * Support of multicast IP addresses.
- Spec cleanup.
* Mon Mar 16 2015 dimstar@opensuse.org
- Add pkgconfig(speexdsp) BuildRequires: it's an explicit
  dependency according to configure; speexdsp was split off of
  libspeex into an own package.
* Sun May 25 2014 fisiu@opensuse.org
- Update to 2.10.0:
  * add HD video support
  * new OpenSLES android sound module
  * update android AEC settings table
  * add opus codec
  * bugfixes
- Build with opus audio codec and upnp support.
* Sun May 25 2014 crrodriguez@opensuse.org
- Use LFS_CFLAGS in 32 bit systems, a mediastreamer without
  large file support is not very pleasant..
- Make the build verbose.
* Mon Aug 12 2013 fisiu@opensuse.org
- Add missing BuildRequires for Video support.
* Tue Jun 25 2013 fisiu@opensuse.org
- Update to 2.9.0:
  * Add support of ICE (RFC 5245).
  * Split the libmediastreamer library in two libraries:
    libmediastreamer_base and libmediastreamer_voip. For VoIP
    support, both libraries must be linked to the executable.
  * API change to the audio_stream_new, video_stream_new,
    audio_stream_start_full, video_stream_start functions to use
    different addresses for RTP and RTCP.
  * Add accessors to set DSCP parameters for media streams.
  * AudioStream recording feature added
  * OpenGL video output for Linux
  * Adaptive bitrate control improvements
  * faster call quality indicator feedback
  * stereo support for L16 codec
- Drop 0001-Fixes-for-new-versions-of-ffmpeg.patch: fixed upstream.
* Mon Jun  3 2013 fisiu@opensuse.org
- Add 0001-Fixes-for-new-versions-of-ffmpeg.patch: fix for new
  ffmpeg API.
- Spec cleanup.
- Call ldconfig for shared library.
- Enable conditional build for "video" configure option.
* Tue Oct 23 2012 jengelh@inai.de
- Implement shared library package
- Language files are named mediastreamer.mo, adjust %%find_lang
* Wed Oct 10 2012 mailaender@opensuse.org
- initial packaging
